@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-"""Back door shell server
+'''Back door shell server
 
 This exposes an shell terminal on a socket.
 
@@ -9,7 +9,29 @@ This exposes an shell terminal on a socket.
     --password : (optional) sets the password to login with
     --port     : set the local port for the server to listen on
     --watch    : show the virtual screen after each client request
-"""
+
+PEXPECT LICENSE
+
+    This license is approved by the OSI and FSF as GPL-compatible.
+        http://opensource.org/licenses/isc-license.txt
+
+    Copyright (c) 2012, Noah Spurrier <noah@noah.org>
+    PERMISSION TO USE, COPY, MODIFY, AND/OR DISTRIBUTE THIS SOFTWARE FOR ANY
+    PURPOSE WITH OR WITHOUT FEE IS HEREBY GRANTED, PROVIDED THAT THE ABOVE
+    COPYRIGHT NOTICE AND THIS PERMISSION NOTICE APPEAR IN ALL COPIES.
+    THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
+    WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
+    MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
+    ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+    WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
+    ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
+    OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+
+'''
+
+from __future__ import print_function
+
+from __future__ import absolute_import
 
 # Having the password on the command line is not a good idea, but
 # then this entire project is probably not the most security concious thing
@@ -19,17 +41,17 @@ import time, sys, os, getopt, getpass, traceback, threading, socket
 
 def exit_with_usage(exit_code=1):
 
-    print globals()['__doc__']
+    print(globals()['__doc__'])
     os._exit(exit_code)
 
 class roller (threading.Thread):
 
-    """This runs a function in a loop in a thread."""
+    '''This runs a function in a loop in a thread.'''
 
     def __init__(self, interval, function, args=[], kwargs={}):
 
-        """The interval parameter defines time between each call to the function.
-        """
+        '''The interval parameter defines time between each call to the function.
+        '''
 
         threading.Thread.__init__(self)
         self.interval = interval
@@ -40,7 +62,7 @@ class roller (threading.Thread):
 
     def cancel(self):
 
-        """Stop the roller."""
+        '''Stop the roller.'''
 
         self.finished.set()
 
@@ -52,8 +74,8 @@ class roller (threading.Thread):
 
 def endless_poll (child, prompt, screen, refresh_timeout=0.1):
 
-    """This keeps the screen updated with the output of the child. This runs in
-    a separate thread. See roller(). """
+    '''This keeps the screen updated with the output of the child. This runs in
+    a separate thread. See roller(). '''
 
     #child.logfile_read = screen
     try:
@@ -76,7 +98,7 @@ def daemonize (stdin='/dev/null', stdout='/dev/null', stderr='/dev/null'):
     case, stdin, stdout and stderr are all set up for you to refer to the
     network connection, and the fork()s and session manipulation should not be
     done (to avoid confusing inetd). Only the chdir() and umask() steps remain
-    as useful. 
+    as useful.
 
     References:
         UNIX Programming FAQ
@@ -94,30 +116,30 @@ def daemonize (stdin='/dev/null', stdout='/dev/null', stderr='/dev/null'):
     expect. '''
 
     # Do first fork.
-    try: 
-        pid = os.fork() 
+    try:
+        pid = os.fork()
         if pid > 0:
             sys.exit(0)   # Exit first parent.
-    except OSError, e: 
+    except OSError as e:
         sys.stderr.write ("fork #1 failed: (%d) %s\n" % (e.errno, e.strerror) )
         sys.exit(1)
 
     # Decouple from parent environment.
-    os.chdir("/") 
-    os.umask(0) 
-    os.setsid() 
+    os.chdir("/")
+    os.umask(0)
+    os.setsid()
 
     # Do second fork.
-    try: 
-        pid = os.fork() 
+    try:
+        pid = os.fork()
         if pid > 0:
             sys.exit(0)   # Exit second parent.
-    except OSError, e: 
+    except OSError as e:
         sys.stderr.write ("fork #2 failed: (%d) %s\n" % (e.errno, e.strerror) )
         sys.exit(1)
 
     # Now I am a daemon!
-    
+
     # Redirect standard file descriptors.
     si = open(stdin, 'r')
     so = open(stdout, 'a+')
@@ -138,8 +160,8 @@ def main ():
 
     try:
         optlist, args = getopt.getopt(sys.argv[1:], 'h?d', ['help','h','?', 'hostname=', 'username=', 'password=', 'port=', 'watch'])
-    except Exception, e:
-        print str(e)
+    except Exception as e:
+        print(str(e))
         exit_with_usage()
 
     command_line_options = dict(optlist)
@@ -147,7 +169,7 @@ def main ():
     # There are a million ways to cry for help. These are but a few of them.
     if [elem for elem in command_line_options if elem in ['-h','--h','-?','--?','--help']]:
         exit_with_usage(0)
-  
+
     hostname = "127.0.0.1"
     port = 1664
     username = os.getenv('USER')
@@ -165,23 +187,23 @@ def main ():
         port = int(options['--port'])
     if '--username' in options:
         username = options['--username']
-    print "Login for %s@%s:%s" % (username, hostname, port)
+    print("Login for %s@%s:%s" % (username, hostname, port))
     if '--password' in options:
         password = options['--password']
     else:
         password = getpass.getpass('password: ')
-   
-    if daemon_mode: 
-        print "daemonizing server"
+
+    if daemon_mode:
+        print("daemonizing server")
         daemonize()
         #daemonize('/dev/null','/tmp/daemon.log','/tmp/daemon.log')
-    
+
     sys.stdout.write ('server started with pid %d\n' % os.getpid() )
 
-    virtual_screen = ANSI.ANSI (24,80) 
+    virtual_screen = ANSI.ANSI (24,80)
     child = pxssh.pxssh()
     child.login (hostname, username, password)
-    print 'created shell. command line prompt is', child.PROMPT
+    print('created shell. command line prompt is', child.PROMPT)
     #child.sendline ('stty -echo')
     #child.setecho(False)
     virtual_screen.write (child.before)
@@ -191,10 +213,10 @@ def main ():
     s = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
     localhost = '127.0.0.1'
     s.bind('/tmp/mysock')
-    os.chmod('/tmp/mysock',0777)
-    print 'Listen'
+    os.chmod('/tmp/mysock',0o777)
+    print('Listen')
     s.listen(1)
-    print 'Accept'
+    print('Accept')
     #s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
     #localhost = '127.0.0.1'
     #s.bind((localhost, port))
@@ -203,13 +225,13 @@ def main ():
 
     r = roller (0.01, endless_poll, (child, child.PROMPT, virtual_screen))
     r.start()
-    print "screen poll updater started in background thread"
+    print("screen poll updater started in background thread")
     sys.stdout.flush()
 
     try:
         while True:
             conn, addr = s.accept()
-            print 'Connected by', addr
+            print('Connected by', addr)
             data = conn.recv(1024)
             if data[0]!=':':
                 cmd = ':sendline'
@@ -244,29 +266,29 @@ def main ():
             response.append (shell_window)
             #response = add_cursor_blink (response, row, col)
             sent = conn.send('\n'.join(response))
-            if watch_mode: print '\n'.join(response)
+            if watch_mode: print('\n'.join(response))
             if sent < len (response):
-                print "Sent is too short. Some data was cut off."
+                print("Sent is too short. Some data was cut off.")
             conn.close()
     finally:
         r.cancel()
-        print "cleaning up socket"
+        print("cleaning up socket")
         s.close()
         if os.path.exists("/tmp/mysock"): os.remove("/tmp/mysock")
-        print "done!"
+        print("done!")
 
 def pretty_box (rows, cols, s):
 
-    """This puts an ASCII text box around the given string, s.
-    """
+    '''This puts an ASCII text box around the given string, s.
+    '''
 
     top_bot = '+' + '-'*cols + '+\n'
     return top_bot + '\n'.join(['|'+line+'|' for line in s.split('\n')]) + '\n' + top_bot
-    
+
 def error_response (msg):
 
     response = []
-    response.append ("""All commands start with :
+    response.append ('''All commands start with :
 :{REQUEST} {ARGUMENT}
 {REQUEST} may be one of the following:
     :sendline: Run the ARGUMENT followed by a line feed.
@@ -279,17 +301,17 @@ Example:
     ls -l
 is equivalent to:
     :sendline ls -l
-""")
+''')
     response.append (msg)
     return '\n'.join(response)
 
 def parse_host_connect_string (hcs):
 
-    """This parses a host connection string in the form
+    '''This parses a host connection string in the form
     username:password@hostname:port. All fields are options expcet hostname. A
     dictionary is returned with all four keys. Keys that were not included are
     set to empty strings ''. Note that if your password has the '@' character
-    then you must backslash escape it. """
+    then you must backslash escape it. '''
 
     if '@' in hcs:
         p = re.compile (r'(?P<username>[^@:]*)(:?)(?P<password>.*)(?!\\)@(?P<hostname>[^:]*):?(?P<port>[0-9]*)')
@@ -299,18 +321,18 @@ def parse_host_connect_string (hcs):
     d = m.groupdict()
     d['password'] = d['password'].replace('\\@','@')
     return d
-     
+
 if __name__ == "__main__":
 
     try:
         start_time = time.time()
-        print time.asctime()
+        print(time.asctime())
         main()
-        print time.asctime()
-        print "TOTAL TIME IN MINUTES:",
-        print (time.time() - start_time) / 60.0
-    except Exception, e:
-        print str(e)
+        print(time.asctime())
+        print("TOTAL TIME IN MINUTES:", end=' ')
+        print((time.time() - start_time) / 60.0)
+    except Exception as e:
+        print(str(e))
         tb_dump = traceback.format_exc()
-        print str(tb_dump)
+        print(str(tb_dump))
 
